@@ -24,7 +24,6 @@ import java.io.OutputStream;
 import java.net.URL;
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -33,12 +32,12 @@ import java.util.Map;
 import java.util.Set;
 import java.util.TreeMap;
 
-import javax.servlet.ServletInputStream;
-import javax.servlet.ServletOutputStream;
-import javax.servlet.http.HttpServletRequest;
-import javax.xml.bind.JAXBElement;
 import javax.xml.namespace.QName;
 
+import jakarta.servlet.ServletInputStream;
+import jakarta.servlet.ServletOutputStream;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.xml.bind.JAXBElement;
 import org.apache.cxf.Bus;
 import org.apache.cxf.BusException;
 import org.apache.cxf.BusFactory;
@@ -71,6 +70,7 @@ import org.apache.cxf.ws.addressing.AddressingProperties;
 import org.apache.cxf.ws.addressing.EndpointReferenceType;
 import org.apache.cxf.ws.addressing.EndpointReferenceUtils;
 import org.apache.cxf.ws.addressing.JAXWSAConstants;
+import org.eclipse.jetty.http.HttpFields;
 import org.eclipse.jetty.server.Request;
 import org.eclipse.jetty.server.Response;
 
@@ -659,15 +659,15 @@ public class JettyHTTPDestinationTest {
                 when(request.getAttribute("org.eclipse.jetty.ajax.Continuation")).thenReturn(null);
                 when(request.getAttribute("http.service.redirection")).thenReturn(null);
 
-                List<String> headers = Arrays.asList(new String[] {"content-type",
-                                                                   JettyHTTPDestinationTest.AUTH_HEADER});
-                List<String> ct = Arrays.asList(new String[] {"text/xml", "charset=utf8"});
-                when(request.getHeaderNames()).thenReturn(Collections.enumeration(headers));
-                when(request.getHeaders("content-type")).thenReturn(Collections.enumeration(ct));
-                when(request.getHeaders(JettyHTTPDestinationTest.AUTH_HEADER))
-                    .thenReturn(Collections
-                               .enumeration(Collections
-                                            .singletonList(JettyHTTPDestinationTest.BASIC_AUTH)));
+                HttpFields.Mutable httpFields = HttpFields.build();
+                httpFields.add("content-type", "text/xml");
+                httpFields.add("content-type", "charset=utf8");
+                httpFields.put(JettyHTTPDestinationTest.AUTH_HEADER, JettyHTTPDestinationTest.BASIC_AUTH);
+
+                when(request.getHeaderNames()).thenReturn(httpFields.getFieldNames());
+                when(request.getHeaders("content-type")).thenReturn(httpFields.getValues("content-type"));
+                when(request.getHeaders(JettyHTTPDestinationTest.AUTH_HEADER)).thenReturn(
+                    httpFields.getValues(JettyHTTPDestinationTest.AUTH_HEADER));
 
                 when(request.getInputStream()).thenReturn(is);
                 doNothing().when(request).setHandled(true);
@@ -681,10 +681,9 @@ public class JettyHTTPDestinationTest {
                     when(response.getStatus()).thenReturn(status);
                     doNothing().when(response).flushBuffer();
                 }
-
-                when(request.getAttribute("javax.servlet.request.cipher_suite")).thenReturn("anythingwilldoreally");
+                when(request.getAttribute("jakarta.servlet.request.cipher_suite")).thenReturn("anythingwilldoreally");
                 when(request.getAttribute("javax.net.ssl.session")).thenReturn(null);
-                when(request.getAttribute("javax.servlet.request.X509Certificate")).thenReturn(null);
+                when(request.getAttribute("jakarta.servlet.request.X509Certificate")).thenReturn(null);
             }
         }
 
