@@ -18,6 +18,9 @@
  */
 package org.apache.cxf.transport.http;
 
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.Closeable;
 import java.io.FilterInputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -106,7 +109,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
     volatile int lastTlsHash = -1;
     volatile URI sslURL;
     private final ReentrantLock initializationLock = new ReentrantLock();
-    
+
     private static final class RefCount<T extends HttpClient> {
         private final AtomicLong count = new AtomicLong();
         private final TLSClientParameters clientParameters;
@@ -120,12 +123,12 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             this.clientParameters = clientParameters;
             this.finalizer = finalizer;
         }
-        
+
         RefCount<T> acquire() {
             count.incrementAndGet();
             return this;
         }
-        
+
         void release() {
             if (count.decrementAndGet() == 0) {
                 finalizer.run();
@@ -157,7 +160,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                         ((AutoCloseable)client).close();
                     } catch (Exception e) {
                         //ignore
-                    }                
+                    }
                 } else if (client != null) {
                     tryToShutdownSelector(client);
                 }
@@ -176,7 +179,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             return clientParameters;
         }
     }
-    
+
     private static final class HttpClientCache {
         private static final int MAX_SIZE = 100; // Keeping at most 100 clients
 
@@ -184,9 +187,9 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
         private final ClientPolicyCalculator cpc = new ClientPolicyCalculator();
         private final ReentrantLock lock = new ReentrantLock();
 
-        RefCount<HttpClient> computeIfAbsent(final boolean shareHttpClient, final HTTPClientPolicy policy, 
+        RefCount<HttpClient> computeIfAbsent(final boolean shareHttpClient, final HTTPClientPolicy policy,
                 final TLSClientParameters clientParameters, final Supplier<HttpClient> supplier) {
-            
+
             // Do not share if it is not allowed for the conduit or cache capacity is exceeded
             if (!shareHttpClient || clients.size() >= MAX_SIZE) {
                 return new RefCount<HttpClient>(supplier.get(), policy, clientParameters, () -> { }).acquire();
@@ -231,7 +234,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
     public HttpClientHTTPConduit(Bus b, EndpointInfo ei, EndpointReferenceType t) throws IOException {
         super(b, ei, t);
     }
-    
+
     private static Set<String> getRestrictedHeaders() {
         Set<String> headers = new TreeSet<>(String.CASE_INSENSITIVE_ORDER);
         headers.addAll(Set.of("Connection", "Content-Length", "Expect", "Host", "Upgrade"));
@@ -243,13 +246,22 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                 || !lastURL.getHost().equals(url.getHost())
                 || lastURL.getPort() != url.getPort();
     }
-    
+
     @Override
     public void close(Message msg) throws IOException {
+        try {
+            OutputStream os = msg.getContent(OutputStream.class);
+            // Java 21 may hang on close, we flush stream to help close them out.
+            if (os != null && AutoCloseable.class.isAssignableFrom(HttpClient.class)) {
+                os.flush();
+            }
+        } catch (IOException ioException) {
+            // ignore
+        }
         super.close(msg);
         msg.remove(HttpClient.class);
     }
-    
+
     /**
      * Close the conduit
      */
@@ -264,17 +276,17 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
     private static void tryToShutdownSelector(HttpClient client) {
         synchronized (client) {
             String n = client.toString();
-    
+
             // it can take three seconds (or more) for the JVM to determine the client
             // is unreferenced and then shutdown the selector thread, we'll try and speed that
-            // up.  This is somewhat of a complete hack.   
+            // up.  This is somewhat of a complete hack.
             int idx = n.lastIndexOf('(');
             if (idx > 0) {
                 n = n.substring(idx + 1);
                 n = n.substring(0, n.length() - 1);
                 n = "HttpClient-" + n + "-SelectorManager";
             }
-            try {        
+            try {
                 ThreadGroup rootGroup = Thread.currentThread().getThreadGroup();
                 Thread[] threads = new Thread[rootGroup.activeCount()];
                 int cnt = rootGroup.enumerate(threads);
@@ -293,7 +305,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             }
         }
     }
-    
+
     @Override
     protected void setupConnection(Message message, Address address, HTTPClientPolicy csPolicy) throws IOException {
         URI uri = address.getURI();
@@ -319,15 +331,15 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                 o = Boolean.TRUE;
             }
             if (clientParameters.isDisableCNCheck()) {
-                if (clientParameters.getSslContext() != null) { 
+                if (clientParameters.getSslContext() != null) {
                     // If they specify their own SSLContext, we cannot handle the
                     // HostnameVerifier so we'll need to use the URLConnection
                     o = Boolean.TRUE;
                 }
-                if (clientParameters.getTrustManagers() != null 
+                if (clientParameters.getTrustManagers() != null
                     && JavaUtils.getJavaMajorVersion() < 14) {
                     // trustmanagers hacks don't work on Java11
-                    o = Boolean.TRUE;                    
+                    o = Boolean.TRUE;
                 }
             }
         }
@@ -336,7 +348,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             super.setupConnection(message, address, csPolicy);
             return;
         }
-        
+
         if (sslURL != null && isSslTargetDifferent(sslURL, uri)) {
             sslURL = null;
             if (clientRef != null) {
@@ -360,20 +372,21 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             HttpClient.Builder cb = HttpClient.newBuilder()
                 .proxy(ps)
                 .followRedirects(Redirect.NEVER);
-            
+
             if (ctimeout > 0) {
                 cb.connectTimeout(Duration.ofMillis(ctimeout));
             }
-            
+
             if ("https".equals(uri.getScheme())) {
                 sslURL = uri;
                 try {
                     SSLContext sslContext = clientParameters.getSslContext();
                     if (sslContext == null) {
-                        sslContext = SSLUtils.getSSLContext(clientParameters, true);                    
+                        sslContext = SSLUtils.getSSLContext(clientParameters, true);
                         cb.sslContext(sslContext);
                     }
                     if (sslContext != null) {
+                        cb.sslContext(sslContext);
                         String[] supportedCiphers =  org.apache.cxf.configuration.jsse.SSLUtils
                                 .getSupportedCipherSuites(sslContext);
                         String[] cipherSuites = org.apache.cxf.configuration.jsse.SSLUtils
@@ -382,13 +395,13 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                                                           sslContext.getSocketFactory().getDefaultCipherSuites(),
                                                           supportedCiphers,
                                                           LOG);
-                        
+
                         if (clientParameters.getSecureSocketProtocol() != null) {
                             String protocol = clientParameters.getSecureSocketProtocol();
                             SSLParameters params = new SSLParameters(cipherSuites, new String[] {protocol});
                             cb.sslParameters(params);
                         } else {
-                            final SSLParameters params = new SSLParameters(cipherSuites, 
+                            final SSLParameters params = new SSLParameters(cipherSuites,
                                 TLSClientParameters.getPreferredClientProtocols());
                             cb.sslParameters(params);
                         }
@@ -402,7 +415,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                 verc = csPolicy.getVersion();
             }
             if ("1.1".equals(HTTP_VERSION) || "1.1".equals(verc)) {
-                cb.version(Version.HTTP_1_1);  
+                cb.version(Version.HTTP_1_1);
             }
 
             // make sure the conduit is not yet initialized
@@ -413,8 +426,8 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                     final boolean shareHttpClient = MessageUtils.getContextualBoolean(message,
                         SHARE_HTTPCLIENT_CONDUIT, true);
                     cl = CLIENTS_CACHE.computeIfAbsent(shareHttpClient, csPolicy, clientParameters, () -> cb.build());
-    
-                    if (!"https".equals(uri.getScheme()) 
+
+                    if (!"https".equals(uri.getScheme())
                         && !KNOWN_HTTP_VERBS_WITH_NO_CONTENT.contains(httpRequestMethod)
                         && cl.client().version() == Version.HTTP_2
                         && ("2".equals(verc) || ("auto".equals(verc) && "2".equals(HTTP_VERSION)))) {
@@ -422,7 +435,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                             // We specifically want HTTP2, but we're using a request
                             // that won't trigger an upgrade to HTTP/2 so we'll
                             // call OPTIONS on the URI which may trigger HTTP/2 upgrade.
-                            // Not needed for methods that don't have a body (GET/HEAD/etc...) 
+                            // Not needed for methods that don't have a body (GET/HEAD/etc...)
                             // or for https (negotiated at the TLS level)
                             HttpRequest.Builder rb = HttpRequest.newBuilder()
                                 .uri(uri)
@@ -431,7 +444,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                         } catch (IOException | InterruptedException e) {
                             //
                         }
-                    } 
+                    }
 
                     clientRef = cl;
                 }
@@ -440,7 +453,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             }
         }
         message.put(HttpClient.class, cl.client());
-        
+
         message.put(KEY_HTTP_CONNECTION_ADDRESS, address);
     }
 
@@ -448,7 +461,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
     protected OutputStream createOutputStream(Message message, boolean needToCacheRequest, boolean isChunking,
                                               int chunkThreshold)
         throws IOException {
-        
+
         Object o = message.get("USING_URLCONNECTION");
         if (Boolean.TRUE == o) {
             return super.createOutputStream(message, needToCacheRequest, isChunking, chunkThreshold);
@@ -507,11 +520,11 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
     static class HttpClientPipedOutputStream extends PipedOutputStream {
         HttpClientWrappedOutputStream stream;
         HTTPClientPolicy csPolicy;
-        HttpClientBodyPublisher publisher;
+        CloseableBodyPublisher publisher;
         HttpClientPipedOutputStream(HttpClientWrappedOutputStream s, 
                                     PipedInputStream pin,
                                     HTTPClientPolicy cp,
-                                    HttpClientBodyPublisher bp) throws IOException {
+                                    CloseableBodyPublisher bp) throws IOException {
             super(pin);
             stream = s;
             csPolicy = cp;
@@ -520,7 +533,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
         public void close() throws IOException {
             super.close();
             csPolicy = null;
-            stream = null;  
+            stream = null;
             if (publisher != null) {
                 publisher.close();
                 publisher = null;
@@ -582,32 +595,33 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             }
         }
     }
-    private static final class InputStreamSupplier implements Supplier<InputStream> {
-        final InputStream in;
-        InputStreamSupplier(InputStream i) {
-            in = i;
-        }
-        
-        public InputStream get() {
-            return in;
-        }
-    }
-    private static final class HttpClientBodyPublisher implements BodyPublisher {
-        PipedInputStream pin;
-        HttpClientWrappedOutputStream  stream;
-        long contentLen;
 
-        private HttpClientBodyPublisher(HttpClientWrappedOutputStream s, PipedInputStream pin) {
+    /**
+     * The interface for {@link BodyPublisher}s that implement {@link Closeable} as well.
+     */
+    private interface CloseableBodyPublisher extends BodyPublisher, Closeable {
+    }
+    
+    /**
+     * The {@link BodyPublisher} that wraps around the output stream.
+     */
+    private static final class HttpClientBodyPublisher implements CloseableBodyPublisher {
+        private Supplier<InputStream> pin;
+        private HttpClientWrappedOutputStream stream;
+        private long contentLen;
+
+        private HttpClientBodyPublisher(HttpClientWrappedOutputStream s, Supplier<InputStream> pin) {
             this.stream = s;
             this.pin = pin;
         }
-        synchronized void close() {
+
+        public synchronized void close() {
             if (stream != null) {
                 contentLen = stream.contentLen;
                 stream = null;
             }
         }
-        
+
         @Override
         public synchronized void subscribe(Subscriber<? super ByteBuffer> subscriber) {
             if (stream != null) {
@@ -615,12 +629,12 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                 contentLen = stream.contentLen;
                 if (stream.pout != null) {
                     synchronized (stream.pout) {
-                        stream.pout.notifyAll();                       
+                        stream.pout.notifyAll();
                     }
                     if (stream != null) {
                         contentLen = stream.contentLen;
                     }
-                    BodyPublishers.ofInputStream(new InputStreamSupplier(pin)).subscribe(subscriber);
+                    BodyPublishers.ofInputStream(pin).subscribe(subscriber);
                     stream = null;
                     pin = null;
                     return;
@@ -637,6 +651,154 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             return contentLen;
         }
     }
+
+    /**
+     * The {@link BodyPublisher} that awaits for the output stream to be fully flushed (closed) 
+     * so the content length becomes known (sized). It is used when the chunked transfer is not allowed
+     * but the content length is not specified up-front.
+     */
+    private static final class HttpClientSizedBodyPublisher implements CloseableBodyPublisher {
+        private HTTPClientPolicy csPolicy;
+        private Supplier<ByteArrayInputStream> pin;
+        private HttpClientWrappedOutputStream stream;
+        private long contentLen;
+
+        private HttpClientSizedBodyPublisher(HttpClientWrappedOutputStream s, HTTPClientPolicy cs,
+                Supplier<ByteArrayInputStream> pin) {
+            this.stream = s;
+            this.csPolicy = cs;
+            this.pin = pin;
+        }
+
+        public synchronized void close() {
+            if (stream != null) {
+                contentLen = stream.contentLen;
+                stream = null;
+            }
+        }
+
+        @Override
+        public synchronized void subscribe(Subscriber<? super ByteBuffer> subscriber) {
+            if (stream != null) {
+                stream.connectionComplete = true;
+                if (stream.pout != null) {
+                    synchronized (stream.pout) {
+                        stream.pout.notifyAll();
+                    }
+
+                    BodyPublishers.ofInputStream(pin).subscribe(subscriber);
+                    stream = null;
+                    pin = null;
+                    return;
+                }
+            }
+            BodyPublishers.noBody().subscribe(subscriber);
+        }
+
+        @Override
+        public long contentLength() {
+            if (stream != null && stream.pout != null) {
+                final CloseableByteArrayOutputStream baos = (CloseableByteArrayOutputStream) stream.pout;
+
+                try {
+                    synchronized (baos) {
+                        if (!baos.closed) {
+                            baos.wait(csPolicy.getConnectionTimeout());
+                        }
+                    }
+                    contentLen = (int) baos.size();
+                } catch (InterruptedException e) {
+                    //ignore
+                }
+            }
+
+            return contentLen;
+        }
+    }
+
+    /**
+     * The {@link ByteArrayOutputStream} implementation that tracks the closeability state.
+     */
+    private static final class CloseableByteArrayOutputStream extends ByteArrayOutputStream {
+        private boolean closed;
+
+        /**
+         * Creates a new output stream for user data
+         */
+        CloseableByteArrayOutputStream() {
+            super(4096);
+        }
+
+        /**
+         * Writes the specified byte to this output stream.
+         *
+         * @param   b   the byte to be written.
+         */
+        public synchronized void write(int b) {
+            if (closed) {
+                return;
+            }
+            super.write(b);
+        }
+
+        /**
+         * Writes <code>len</code> bytes from the specified byte array
+         * starting at offset <code>off</code> to this output stream.
+         *
+         * @param   b     the data.
+         * @param   off   the start offset in the data.
+         * @param   len   the number of bytes to write.
+         */
+        public synchronized void write(byte[] b, int off, int len) {
+            if (closed) {
+                return;
+            }
+            super.write(b, off, len);
+        }
+
+        /**
+         * Resets the <code>count</code> field of this output
+         * stream to zero, so that all currently accumulated output in the
+         * output stream is discarded. The output stream can be used again,
+         * reusing the already allocated buffer space. If the output stream
+         * has been closed, then this method has no effect.
+         *
+         * @see     java.io.ByteArrayInputStream#count
+         */
+        public synchronized void reset() {
+            if (closed) {
+                return;
+            }
+            super.reset();
+        }
+
+        /**
+         * After close() has been called, it is no longer possible to write
+         * to this stream. Further calls to write will have no effect.
+         */
+        public synchronized void close() throws IOException {
+            closed = true;
+            super.close();
+            notifyAll();
+        }
+
+        /**
+         * Returns new instance of the {@link ByteArrayInputStream} that uses the same underlying buffer as 
+         * this stream. The steam must be closed in order to ensure no further modifications could happen. 
+         * @return new instance of the {@link ByteArrayInputStream}
+         */
+        public ByteArrayInputStream getInputStream() {
+            if (!closed) {
+                throw new IllegalStateException("The stream is not closed and underlying buffer "
+                        + "could still be changed");
+            }
+
+            // Creates new ByteArrayInputStream instance that respects the current state of the buffer 
+            // (since ByteArrayInputStream::toByteArray() does array copy).
+            return new ByteArrayInputStream(this.buf, 0, this.count);
+        }
+    }
+
     class HttpClientWrappedOutputStream extends WrappedOutputStream {  
 
         List<Flow.Subscriber<? super ByteBuffer>> subscribers = new LinkedList<>();
@@ -645,11 +807,11 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
         int rtimeout;
         volatile Throwable exception;
         volatile boolean connectionComplete;
-        PipedOutputStream pout;
-        HttpClientBodyPublisher publisher;
+        OutputStream pout;
+        CloseableBodyPublisher publisher;
         HttpRequest request;
-        
-        
+
+
         HttpClientWrappedOutputStream(Message message,
                                       boolean needToCacheRequest, boolean isChunking,
                                       int chunkThreshold, String conduitName) {
@@ -659,17 +821,30 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
 
         @Override
         public void close() throws IOException {
-            super.close();
-            if (pout != null) {
-                pout.close();
-                pout = null;
+            try {
+                super.close();
+            } finally {
+                if (pout != null) {
+                    try {
+                        pout.close();
+                    } catch (IOException e) {
+                        logStackTrace(e);
+                    }
+                    pout = null;
+                }
+                if (publisher != null) {
+                    try {
+                        publisher.close();
+                    } catch (IOException e) {
+                        logStackTrace(e);
+                    }
+                    publisher = null;
+                }
+                request = null;
+                subscribers = null;
             }
-            if (publisher != null) {
-                publisher.close();
-                publisher = null;
-            }
-            request = null;
-            subscribers = null;            
+            
+            
         }
         void addSubscriber(Flow.Subscriber<? super ByteBuffer> subscriber) {
             subscribers.add(subscriber);
@@ -679,7 +854,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
         protected void setFixedLengthStreamingMode(int i) {
             contentLen = i;
         }
-        
+
         @Override
         protected void handleNoOutput() throws IOException {
             contentLen = 0;
@@ -738,9 +913,9 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                 if (!dropContentType) {
                     rb.header(HttpHeaderHelper.CONTENT_TYPE, h.determineContentType());
                 }
-            }            
+            }
         }
-        
+
         private boolean isConnectionAttemptCompleted(HTTPClientPolicy csPolicy, PipedOutputStream out)
             throws IOException {
             if (!connectionComplete) {
@@ -775,8 +950,8 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             }
             return true;
         }
-        
-        
+
+
         @Override
         protected void setProtocolHeaders() throws IOException {
             HttpClient cl = outMessage.get(HttpClient.class);
@@ -785,29 +960,37 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             String httpRequestMethod =
                 (String)outMessage.get(Message.HTTP_REQUEST_METHOD);
 
-            
+
             if (KNOWN_HTTP_VERBS_WITH_NO_CONTENT.contains(httpRequestMethod)
                 || PropertyUtils.isTrue(outMessage.get(Headers.EMPTY_REQUEST_PROPERTY))) {
                 contentLen = 0;
             }
 
-            final PipedInputStream pin = new PipedInputStream(csPolicy.getChunkLength() <= 0
-                ? 4096 : csPolicy.getChunkLength());
-            
-            this.publisher = new HttpClientBodyPublisher(this, pin);
-            if (contentLen != 0) {
-                pout = new HttpClientPipedOutputStream(this, pin, csPolicy, publisher);
+            if (csPolicy.isAllowChunking() || contentLen >= 0) {
+                final PipedInputStream pin = new PipedInputStream(csPolicy.getChunkLength() <= 0
+                        ? 4096 : csPolicy.getChunkLength());
+                this.publisher = new HttpClientBodyPublisher(this, () -> pin);
+                if (contentLen != 0) {
+                    pout = new HttpClientPipedOutputStream(this, pin, csPolicy, publisher);
+                }
+            } else if (contentLen != 0) {
+                // If chunking is not allowed but the contentLen is unknown (-1), we need to
+                // buffer the request body stream until it is fully flushed by the client and only
+                // than send the request.
+                final CloseableByteArrayOutputStream baos = new CloseableByteArrayOutputStream();
+                this.publisher = new HttpClientSizedBodyPublisher(this, csPolicy, baos::getInputStream);
+                pout = baos;
             }
 
             HttpRequest.Builder rb = HttpRequest.newBuilder()
-                .method(httpRequestMethod, publisher);  
+                .method(httpRequestMethod, publisher);
             String verc = (String)outMessage.getContextualProperty(FORCE_HTTP_VERSION);
             if (verc == null) {
                 verc = csPolicy.getVersion();
             }
             if ("1.1".equals(HTTP_VERSION) || "1.1".equals(verc)) {
-                rb.version(Version.HTTP_1_1);  
-            }            
+                rb.version(Version.HTTP_1_1);
+            }
             try {
                 rb.uri(address.getURI());
             } catch (IllegalArgumentException iae) {
@@ -815,17 +998,17 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                 mex.initCause(iae);
                 throw mex;
             }
-            
+
             rtimeout = determineReceiveTimeout(outMessage, csPolicy);
             if (rtimeout > 0) {
                 rb.timeout(Duration.ofMillis(rtimeout));
             }
 
             setProtocolHeadersInBuilder(rb);
-                
+
             request = rb.build();
-            
-            
+
+
             final BodyHandler<InputStream> handler =  BodyHandlers.ofInputStream();
             if (System.getSecurityManager() != null) {
                 try {
@@ -891,7 +1074,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                         uhe.initCause(cause);
                         throw uhe;
                     }
-                        
+
                 }
                 if (t instanceof IOException) {
                     IOException iot = (IOException)t;
@@ -903,9 +1086,9 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             } catch (TimeoutException e) {
                 throw (IOException)(new HttpTimeoutException("Timeout").initCause(e));
             }
-            
+
         }
-        
+
         @Override
         protected int getResponseCode() throws IOException {
             return getResponse().statusCode();
@@ -917,13 +1100,13 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             h.readFromConnection(rsp.headers().map());
             if (rsp.headers().map().containsKey(Message.CONTENT_TYPE)) {
                 List<String> s = rsp.headers().allValues(Message.CONTENT_TYPE);
-                inMessage.put(Message.CONTENT_TYPE, String.join(",", s));                
+                inMessage.put(Message.CONTENT_TYPE, String.join(",", s));
             } else {
                 inMessage.put(Message.CONTENT_TYPE, null);
             }
             cookies.readFromHeaders(h);
         }
-        
+
         @Override
         protected InputStream getInputStream() throws IOException {
             HttpResponse<InputStream> resp = getResponse();
@@ -1014,18 +1197,18 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             }
             return null;
         }
-        
+
         @Override
         protected HttpsURLConnectionInfo getHttpsURLConnectionInfo() throws IOException {
             Address addrss = (Address)outMessage.get(KEY_HTTP_CONNECTION_ADDRESS);
             URI uri = addrss.getURI();
-            
+
             if ("http".equals(uri.getScheme())) {
                 return null;
             }
             String method = (String)outMessage.get(Message.HTTP_REQUEST_METHOD);
             HttpClient cl = outMessage.get(HttpClient.class);
-            
+
             while (!connectionComplete || !cl.sslContext().getClientSessionContext().getIds().hasMoreElements()) {
                 Thread.yield();
             }
@@ -1036,15 +1219,15 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
             Principal principal = session.getLocalPrincipal();
             Certificate[] serverCerts = session.getPeerCertificates();
             Principal peer = session.getPeerPrincipal();
-            
+
             HttpsURLConnectionInfo info = new HttpsURLConnectionInfo(uri, method, cipherSuite,
                                                                      localCerts, principal,
                                                                      serverCerts, peer);
-            
+
             return info;
         }
 
-        
+
 
         @Override
         protected boolean usingProxy() {
@@ -1070,7 +1253,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
                 } catch (IOException ioe) {
                     // ignore
                 }
-            }            
+            }
             // Don't need to do anything
             return null;
         }
@@ -1078,7 +1261,7 @@ public class HttpClientHTTPConduit extends URLConnectionHTTPConduit {
         @Override
         protected void setupNewConnection(String newURL) throws IOException {
             connectionComplete = false;
-            
+
             HTTPClientPolicy cp = getClient(outMessage);
             Address address;
             try {
