@@ -21,6 +21,7 @@ package org.apache.cxf.systest.jaxrs.cdi.jetty;
 import java.util.UUID;
 
 import jakarta.ws.rs.core.Form;
+import jakarta.ws.rs.core.MediaType;
 import jakarta.ws.rs.core.Response;
 import org.apache.cxf.jaxrs.model.AbstractResourceInfo;
 import org.apache.cxf.systests.cdi.base.AbstractCdiSingleAppTest;
@@ -85,6 +86,18 @@ public class JettyEmbeddedTest extends AbstractCdiSingleAppTest {
         assertEquals(Response.Status.CREATED.getStatusCode(), r.getStatus());
     }
 
+    @Test
+    public void testConfiguredProviders() {
+        assertEquals("AtomFeedProvider,"
+                + "CustomContextFeature,"
+                + "JacksonJsonProvider,"
+                + "JacksonJsonProvider,"
+                + "SampleFeature,"
+                + "SampleNestedFeature,"
+                + "ValidationExceptionMapper",
+            createWebClient(getBasePath() + "/providers", MediaType.TEXT_PLAIN).get(String.class).trim());
+    }
+
     @Override
     protected int getPort() {
         return EmbeddedJettyServer.PORT;
